+++
title = "Platform APIs and Services"
weight = 100
toc = true
aliases = [
    "/old-developer/latest/apis.html",
    "/old-developer/latest/apps-core.html",
    "/old-developer/latest/connectivity.html",
    "/old-developer/latest/framework-app.html",
    "/old-developer/latest/framework-ui.html",
    "/old-developer/latest/infrastructure-ui.html",
    "/old-developer/latest/internet.html",
    "/old-developer/latest/multimedia.html",
    "/old-developer/latest/navigation.html",
    "/old-developer/latest/sdk-techs.html",
    "/old-developer/latest/telephony.html",
    "/old-developer/latest/telephony-ip.html",
    "/old-developer/v2019/apis.html",
    "/old-developer/v2019/apps-core.html",
    "/old-developer/v2019/connectivity.html",
    "/old-developer/v2019/framework-app.html",
    "/old-developer/v2019/framework-ui.html",
    "/old-developer/v2019/infrastructure-ui.html",
    "/old-developer/v2019/internet.html",
    "/old-developer/v2019/multimedia.html",
    "/old-developer/v2019/navigation.html",
    "/old-developer/v2019/sdk-techs.html",
    "/old-developer/v2019/telephony.html",
    "/old-developer/v2019/telephony-ip.html",
    "/old-developer/v2020/apis.html",
    "/old-developer/v2020/apps-core.html",
    "/old-developer/v2020/connectivity.html",
    "/old-developer/v2020/framework-app.html",
    "/old-developer/v2020/framework-ui.html",
    "/old-developer/v2020/infrastructure-ui.html",
    "/old-developer/v2020/internet.html",
    "/old-developer/v2020/multimedia.html",
    "/old-developer/v2020/navigation.html",
    "/old-developer/v2020/sdk-techs.html",
    "/old-developer/v2020/telephony.html",
    "/old-developer/v2020/telephony-ip.html",
    "/old-developer/v2021pre/apis.html",
    "/old-developer/v2021pre/apps-core.html",
    "/old-developer/v2021pre/connectivity.html",
    "/old-developer/v2021pre/framework-app.html",
    "/old-developer/v2021pre/framework-ui.html",
    "/old-developer/v2021pre/infrastructure-ui.html",
    "/old-developer/v2021pre/internet.html",
    "/old-developer/v2021pre/multimedia.html",
    "/old-developer/v2021pre/navigation.html",
    "/old-developer/v2021pre/sdk-techs.html",
    "/old-developer/v2021pre/telephony.html",
    "/old-developer/v2021pre/telephony-ip.html",
    "/old-developer/v2022dev0/apis.html",
    "/old-developer/v2022dev0/apps-core.html",
    "/old-developer/v2022dev0/connectivity.html",
    "/old-developer/v2022dev0/framework-app.html",
    "/old-developer/v2022dev0/framework-ui.html",
    "/old-developer/v2022dev0/infrastructure-ui.html",
    "/old-developer/v2022dev0/internet.html",
    "/old-developer/v2022dev0/multimedia.html",
    "/old-developer/v2022dev0/navigation.html",
    "/old-developer/v2022dev0/sdk-techs.html",
    "/old-developer/v2022dev0/telephony.html",
    "/old-developer/v2022dev0/telephony-ip.html",
    "/old-wiki/Packages",
    "/architecture/apis-and-services"
]
date = "2016-04-20"
lastmod = "2021-11-10"
+++

Apertis follows an app-centric architecture. This means that the
development is more vertical and not layered as in automotive domain.
This reduces dependency and leads to less time to market.

SDK is designed to make app development fast and easy while maintaining
backward compatibility. The system gets upgraded periodically; however
the applications should not be affected. This is achieved by writing
apps against SDK APIs. The SDK APIs are ensured to maintained backward
compatibility.

The SDK will not only expose native system services integrated into the
OS, but also complete high level features which are of interest for
multiple Applications. The APIs are classified into Enabling APIs and SDK APIs.

- **SDK APIs**: Realize the high level features of the SDK behind the scene
  (e.g. an adressbook service which can be used by Apps to store and retrieve
  contact data in a joint place). They are dedicated APIs, provided with good
  documentation and sample code, easy to use and with backward compatibility
  guaranteed exposed with the intention to be used by the Apps.

- **Enabling APIs**: These are APIs from libraries/services that are typically
  taken from Open Source (for example, Telepathy, Tracker). Apps which use
  these APIs directly need to maintain the stability on their own due to API or
  ABI breakages. Effort may be made to ease or remove transition issues when
  ABI or API breakages happen.

  Trying to encapsulate these into SDK APIs will be a continuous process within
  Apertis.

- **OS APIs**: These are more fundamental APIs, usually used by the Enabling
  APIs to provide higher-level functionality. Platform upgrades may require
  adapting applications to new APIs and/or ABIs for these.

{{% notice info %}}
Please see the
[contribution process](contribution_process/#adding-components-to-apertis) for
guidance if your application depends on a component that is not including in
Apertis.
{{% /notice %}}

{{% notice note %}}
Many of the Apertis specific packages are named after sites in the UK where
significant Roman archaeological hoards were found.
{{% /notice %}}

# Infrastructure

Some infrastructure applications and services also need to be available as part of the
system to provide the basic UI even if there are no user focused applications:

## Enabling Components
- [PolicyKit](https://www.freedesktop.org/software/polkit/docs/latest/polkit.8.html):
  System policy management
- [libsecret](https://gnome.pages.gitlab.gnome.org/libsecret/): Secrets management

## OS APIs

- [eglibc](http://www.gnu.org/software/libc/manual/html_node/index.html): Basic OS interfaces
- [GLib](https://docs.gtk.org/glib/): Basic programming framework
- [OSTree](https://ostreedev.github.io/ostree/): Atomic software updates
- [systemd](https://www.freedesktop.org/wiki/Software/systemd/): Service
  management service, used as both a system service and a user service. The
  system instance is process 1 (the first process launched by the kernel after
  leaving the early-boot environment), and is responsible for starting and
  monitoring all system services and all user sessions. The per-user instance,
  `systemd --user`, manages user services.

## Full package index

[source package indices](https://infrastructure.pages.apertis.org/dashboard/tsv/index.html):
Full package list in TSV format, categorized under different repository components, per platform release

# UI Framework

## Provides

- In apertis, Clutter library is provided for UI creation.
- Clutter is an open source software library for creating fast,
  compelling, portable, and dynamic graphical user interfaces.
- Use Open GLES for rendering.
- Comes with rich animation f/w with vast gesture support.
- Provides layout management for easy lay-outing of widgets.

## Enabling Components

- [Cairo](https://www.cairographics.org/): Drawing library
- [GTK+ 3](https://docs.gtk.org/gtk3/): UI toolkit
- [Qt](https://www.qt.io/): UI toolkit

## OS APIs

- [gdk-pixbuf](https://docs.gtk.org/gdk-pixbuf/): Image manipulation
- [pixman](https://www.pixman.org/): Low-level graphics
- [Pango](https://pango.gnome.org/): High-level font rendering
- [Mesa](https://docs.mesa3d.org/): Low-level graphics
- [harfbuzz](https://harfbuzz.github.io/): Low-level font rendering
- [freetype](https://www.freetype.org/freetype2/docs/documentation.html): Low-level font rendering
- [JSON GLib](https://gnome.pages.gitlab.gnome.org/json-glib/): (De)serialization of JSON
- [LLVM](https://llvm.org/docs/): Compiler technology
- [libxml2](https://gnome.pages.gitlab.gnome.org/libxml2/devhelp/): XML Parsing
- [libxslt](https://gnome.pages.gitlab.gnome.org/libxslt/devhelp/): XML Transformation

# Application Framework

## Provides

- Launching a new Application (Launch-mgr)
- Explicit or implicit information (Combination of Action, URI, and
  MIME) can be used to determine an app to launch
- Application life cycle management (activity-mgr)
- Managing application launch history (LUM)
- Audio management and audio priority handling(audio-manager)
- Sharing mechanism
- Application preferences (prefernce-mgr)
- IPC communication (D-Bus)
- View switching and in app back handling (View-Manager)

## SDK services

- **Didcot**: Service which mediates file opening by media type (content type,
  MIME type), URL opening by URL scheme, and other data sharing between user
  applications.

  | Purpose | Git repository |
  |---------|----------------|
  | Data sharing and file opening service | <https://gitlab.apertis.org/appfw/didcot> |

- **Newport**: It manages large downloads for applications and other services
  running on the system (browser, email, other devices, etc).

  | Purpose | Git repository |
  |---------|----------------|
  | Download manager | <https://gitlab.apertis.org/appfw/newport> |

- **Rhosydd/Croesor**: Rhosydd and Croesor are system services for handling
  access to sensors and actuators from applications. It provides a
  vendor-specific hardware API to connect to the services which control the
  hardware, and a SDK API for applications to use to access it.

  | Purpose | Git repository |
  |---------|----------------|
  | Handling access to sensors and actuators | <https://gitlab.apertis.org/appfw/rhosydd> |
  | Sensor backend utilities                 | <https://gitlab.apertis.org/appfw/rhosydd> |

## OS APIs

- [SQLite](https://sqlite.org/docs.html): Data storage
- [GMime](https://github.com/jstedfast/gmime/): File format support
- [D-Bus](https://www.freedesktop.org/wiki/Software/dbus/): `dbus-daemon` is a
  platform component, used as both a user service and a system service. The
  system bus, `dbus-daemon --system`, connects applications and platform
  components to system services, and mediates their access to those system
  services. All components that are able to connect to the system bus may
  listen for signals (normally broadcasts) from authorized system services. All
  other accesses, including sending signals, are prevented unless they are
  specifically allowed by configuration. The per-user session bus, `dbus-daemon
  --session`, is a user service which connects user applications and user
  services together and mediates their communication.

# Connectivity

## Provides

- Cellular and Wi-Fi Connection
  - Connman manages internet connections (Automatically connects to
    last used network).
- Bluetooth
  - Based on Bluez and profiles (PBAP, A2DP, PAN)
  - Discovering / bonding / getting contacts from cell phone

## SDK services

- Beckfoot: Beckfoot is performs connection management and handles
  system connectivity services like network handling, wifi management,
  management of Bluetooth devices etc.

## Enabling components

## OS APIs

- [Bluez](https://www.bluez.org/): Bluetooth technology

# Internet Services

## Provides

- http clients
- Connected services (PIM)

## Enabling components

- [libcurl](https://curl.se/libcurl/): the multiprotocol file transfer library
- [libecal (Evolution Data Sever)](https://developer.gnome.org/libecal/stable/)

## OS APIs

- [Folks](https://gitlab.gnome.org/GNOME/folks): Aggregation of contacts &
  calendaring information
- [Soup](https://libsoup.org/): HTTP client/server
  library for GNOME

# Multimedia

## Provides

- Playback of audio and video contents (local and streaming)
- Capturing images and recording audio and video
- Scanning & Playback of radio
- Complete audio management
- Extracting and displaying media content information
- Integration of External apps like VLC.

## SDK services

- **Prestwood**: This service manages media and handles any activity related to
  the removable media (such as mounting them), UPnP devices, etc and indicates
  when they are ready for other services to communicate with them.

  | Purpose | Git repository |
  |---------|----------------|
  | Disk mounting service | <https://gitlab.apertis.org/hmi/prestwood> |

## Enabling components

- Audio Manager: Audio Policy Management
- PulseAudio: Software mixing multiple audio streams
- Multiple-Format Codec: Various support of codec
- Media Content Service: Content management for media files
- [WebKitGTK+](https://webkitgtk.org/): Web engine
- [Poppler](https://poppler.freedesktop.org/): PDF rendering
- [Canberra](http://0pointer.de/lennart/projects/libcanberra/gtkdoc/):
  High-level sounds
- [Grilo](https://gitlab.gnome.org/GNOME/grilo): Media indexing
- [Tracker-extract](https://gitlab.gnome.org/GNOME/localsearch),
  [Tracker-miner](https://gitlab.gnome.org/GNOME/localsearch),
  [Tracker-sparql](https://gitlab.gnome.org/GNOME/tinysparql): Media
  indexing

# OS APIs

- [GStreamer](https://gstreamer.freedesktop.org/documentation/): Low-level multimedia

  {{% notice note %}}
  Apertis deploys only license verified Gstreamer plugins. Each Gstreamer plugin
  is developed under the [LGPL](https://www.gnu.org/licenses/lgpl.html) license,
  but only gstreamer [core](https://gitlab.freedesktop.org/gstreamer/gstreamer),
  [base](https://gitlab.freedesktop.org/gstreamer/gstreamer/-/tree/main/subprojects/gst-plugins-base) and
  [good](https://gitlab.freedesktop.org/gstreamer/gstreamer/-/tree/main/subprojects/gst-plugins-good) provide license
  and patent-free plugins. The
  [ugly](https://gitlab.freedesktop.org/gstreamer/gstreamer/-/tree/main/subprojects/gst-plugins-ugly) and
  [bad](https://gitlab.freedesktop.org/gstreamer/gstreamer/-/tree/main/subprojects/gst-plugins-bad) plugins are not
  considered safe from the license and patent issues. The "bad"
  plugins usually have API stablity issues as well as license problems. In
  addition, the plugins which have potential issues with patents, or license fees
  should be located in "ugly". For more information, please refer to
  [gstreamers documentation](https://gstreamer.freedesktop.org/documentation/additional/splitup.html).
  {{% /notice %}}

# Navigation

## Provides

- Location based services
- Map
- Route guidance

## SDK services

- **Traprain**: Traprain is a set of libraries allowing navigation services,
  such as a car GPS routing application, to share navigation and routing
  information to third party applications.

  | Purpose | Git repository |
  |---------|----------------|
  | Navigation and routing libraries | <https://gitlab.apertis.org/appfw/traprain> |

## Enabling components

- Geoclue – Deliver location info from various positioning sources
  (http://freedesktop.org/wiki/Software/GeoClue/)
- libchamplain – Map rendering
  (https://wiki.gnome.org/Projects/libchamplain)

# Telephony

## Provides

- Call handling

## Enabling components

- [ofono](https://01.org/ofono) - includes consistent, minimal, and easy to use
  complete APIs for telephony

# VoIP, IM and Groupware

## Provides

- IP telephony
- Chat, *etc*.

## Enabling components

- [Telepathy-GLib](https://telepathy.freedesktop.org/doc/telepathy-glib/)
- [Telepathy](https://telepathy.freedesktop.org/doc/book/index.html): Communication framework
- [libGData](https://gitlab.gnome.org/GNOME/libgdata/)
- SyncEvolution D-Bus (https://syncevolution.org/)

## OS APIs
- [Farstream](https://www.freedesktop.org/wiki/Software/Farstream/#documentation): Communication

